@@ -360,8 +360,8 @@ class Ssh(object):
 
     def read_prompt(self):
         """
-        Read up to 10 blocks until we can identify the shell prompt
-        prompt is stored in self.prompt
+        Reads up to 10 blocks until we can identify the shell prompt
+        Once found, prompt is stored in self._prompt
         It can be called after a shell_send to make sure we have received an
         acknowledgment prompt from the device
         While waiting for prompt, all output received is stored in the
@@ -369,16 +369,15 @@ class Ssh(object):
 
         Prompt may or may not have vdom so it may have 2 forms like
         FGT-1B2-9 #  or  FGT-1B2-9 (vdom)  or even FGT-1B2-9 (global) #
-
         for form with global or vdom, we would match once the first ( is found
 
+        #210825 ESX system prompt is different: [root@neutron:~]
+
         Returns True if prompt si found
         """
         log.info("Enter")
-
         prompt = ""
         round = 1
-
         found = False
         while (not found and round <= 10):
             log.debug("wait for prompt round={}".format(round))
@@ -389,12 +388,10 @@ class Ssh(object):
                         decoded_line = line.decode('utf-8')
                     else:
                         decoded_line = line
-
                     log.debug("decoded_line={}".format(decoded_line))
-
                     # Store decoded lines in ssh.output
                     self.output += decoded_line+"\n"
-                    search_prompt = '(^[A-Za-z0-9@~\:_-]+\s*(?:\$|\#|\())\s?'
+                    search_prompt = '(^\[?[A-Za-z0-9@~\:_-]+\s*(?:\$|\#|\~|\(|\]))\s?'
                     match_prompt = re.search(search_prompt, decoded_line)
                     if match_prompt:
                         prompt = match_prompt.groups(0)[0]
@@ -585,7 +582,7 @@ class Ssh(object):
         Opens tracefile, write and close
         """
         log.debug("Enter with line={}".format(line))
-        
+
         if not self._traceflag:
             return
 
